@@ -1,36 +1,8 @@
-"""Module for basic interaction with user, including logging for debugging.
-
-This module is duplicated from another project called "fmu.config"
-
-Logging is enabled by setting a environment variable::
-
-  export FMU_LOGGING_LEVEL=INFO   # if bash; will set logging to INFO level
-  setenv FMU_LOGGING_LEVEL INFO   # if tcsh; will set logging to INFO level
-
-Other levels are DEBUG, ERROR and CRITICAL. WARNING is default.
-
-Usage of logging in scripts::
-
-  from fmu.ensemble import etc
-  fmux = etc.Interaction()
-  logger = fmux.basiclogger(__name__)
-  logger.info('This is logging of %s', something)
-
-Other than logging, there is also a template for user interaction, which shall
-be used in client scripts::
-
-  fmux.echo('This is a message')
-  fmux.warn('This is a warning')
-  fmux.error('This is an error, will continue')
-  fmux.critical('This is a big error, will exit')
-
-Ind finally, there is a template for setting up a header for applications, see
-the ```print_fmu_header``` method
-
-"""
+"""This module is deprecated and will be removed in fmu-ensemble v2.0.0"""
 
 import os
 import sys
+import warnings
 import inspect
 import logging
 import timeit
@@ -65,7 +37,10 @@ class Interaction(object):
     """
 
     def __init__(self):
-
+        warnings.warn(
+            "fmu.ensemble.etc is deprecated and will be removed in later versions.",
+            DeprecationWarning,
+        )
         self._callclass = None
         self._caller = None
         self._lformat = None
