@@ -1,14 +1,12 @@
 """Module for handling linear combinations of realizations. """
 
 import fnmatch
+import logging
 
 import numpy as np
 import pandas as pd
 
-from .etc import Interaction
-
-xfmu = Interaction()
-logger = xfmu.functionlogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 class RealizationCombination(object):
